SystemOrganization addCategory: #'Seaside-Environment'!

WAObject subclass: #WAAdmin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAAdmin class methodsFor: 'private' stamp: 'jf 1/30/2009 17:40'!
applicationDefaults
	^ WASharedConfiguration named: 'Application Defaults' ifNew: [ :config |
		config
			addParent: WARenderLoopConfiguration instance;
			at: #exceptionHandler put: WAHtmlErrorHandler;
			at: #responseFactory put: WAHtmlResponseFactory ]! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 9/17/2008 20:58'!
clearConfigurationCaches
	WASystemConfiguration clearAllDescriptions! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 10/27/2008 11:27'!
clearSessions
	WARegistry clearAll! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 1/30/2009 17:35'!
configureNewApplication: anApplication
	anApplication configuration
		removeParent: WAApplicationConfiguration instance; "make the chain slightly cleaner"
		addParent: WARenderLoopConfiguration instance;
		addParent: self applicationDefaults.! !

!WAAdmin class methodsFor: 'private' stamp: 'jf 10/26/2008 12:19'!
defaultDispatcher
	^ WADispatcher default! !

!WAAdmin class methodsFor: 'initialization' stamp: 'lr 10/21/2008 15:35'!
initialize
	self reloadApplications! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 1/30/2009 17:35'!
register: aComponentClass asApplicationAt: aString
	"Use this to programatically register a component as an application."
	"WARenderLoopConfiguration is added by default because most users will use WASession and the Render Loop."
	| application |
	application := self register: WAApplication at: aString.
	self configureNewApplication: application.
	application preferenceAt: #rootClass put: aComponentClass.
	^ application! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 1/22/2009 02:43'!
register: aComponentClass asApplicationAt: aString user: user password: password
	"Like #register:asApplicationAt: but additionally adds password protection."
	| application |
	application := self register: aComponentClass asApplicationAt: aString.
	application configuration addParent: WAAuthConfiguration instance.
	application 
		preferenceAt: #login
		put: user.
	application 
		preferenceAt: #passwordHash
		put: (WAPlatform current secureHashFor: password).
	application
		addFilter: WAAuthenticationFilter new.
	^ application! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 10/26/2008 12:19'!
register: anEntryPointClass at: aString
	^ self register: anEntryPointClass at: aString in: self defaultDispatcher! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 10/26/2008 12:15'!
register: anEntryPointClass at: aString in: aDispatcher
	| path dispatcher |
	path := aString findTokens: '/'.
	dispatcher := path allButLast
		inject: aDispatcher
		into: [ :result :each |
			result entryPoints 
				at: each
				ifAbsent: [ result register: (WADispatcher named: each) ] ].
	^ dispatcher register: (anEntryPointClass named: path last)! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 10/26/2008 18:10'!
registerDefaultComponents
	WAPresenter allSubclasses do: [ :each |
		(each class includesSelector: #initialize)
			ifTrue: [ each initialize ] ]! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 11/9/2008 18:00'!
registerDefaultRequestHandlers
	WAFileHandler default: (WAFileHandler named: 'files').
	WAFileHandler default preferenceAt: #fileHandlerListingClass put: WAHtmlFileHandlerListing.
	WADispatcher default register: WAFileHandler default! !

!WAAdmin class methodsFor: 'development' stamp: 'lr 10/21/2008 15:30'!
reloadApplications
	WADispatcher resetDefault.
	WASystemConfiguration clearAllDescriptions.
	self registerDefaultRequestHandlers.
	self registerDefaultComponents! !

WAErrorHandler subclass: #WAHtmlErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlErrorHandler commentStamp: 'jf 11/10/2008 10:07' prior: 0!
This exception handler returns a simple HTML error message response for Warnings and Errors.

It provides two methods to allow the easy creation of custom error responses:

#titleForException:  - can be used to override the text displayed in the title
#renderContentForException:  - can be used to fully customize the HTML output!

!WAHtmlErrorHandler methodsFor: 'actions' stamp: 'lr 1/21/2009 18:19'!
handleDefault: anException
	self requestContext response
		internalError;
		contentType: WAMimeType textHtml;
		nextPutAll: (self rendererClass builder
			fullDocument: true;
			rootBlock: [ :root | root title: (self titleForException: anException) ];
			render: [ :html | self renderContentForException: anException on: html ]).
	self requestContext respond! !

!WAHtmlErrorHandler methodsFor: 'actions' stamp: 'jf 11/10/2008 10:04'!
renderContentForException: anException on: html
	html heading level1; with: anException description.
	html paragraph: 'Your request could not be completed. An exception occurred.'! !

!WAHtmlErrorHandler methodsFor: 'accessing' stamp: 'jf 12/29/2008 19:27'!
rendererClass
	^ WARenderCanvas! !

!WAHtmlErrorHandler methodsFor: 'content' stamp: 'jf 9/14/2008 20:28'!
titleForException: anException
	^ anException description! !

!WADispatcher class methodsFor: '*seaside-environment' stamp: 'lr 12/30/2008 12:48'!
resetAll
	self
		seasideDeprecatedApi: 'WADispatcher class>>#resetAll'
		details: 'Use WAAdmin>>#reloadApplications.'.
	WAAdmin reloadApplications! !

!WAEntryPoint class methodsFor: '*seaside-environment' stamp: 'lr 12/30/2008 12:48'!
register: aString
	self
		seasideDeprecatedApi: 'WAEntryPoint class>>#register:'
		details: 'Use WAAdmin class>>#register:at:.'.
	^ WAAdmin register: self at: aString! !

!WAEntryPoint class methodsFor: '*seaside-environment' stamp: 'lr 12/30/2008 12:48'!
register: aString in: aDispatcher
	self
		seasideDeprecatedApi: 'WAEntryPoint class>>#register:in:'
		details: 'Use WAAdmin class>>#register:at:in:.'.
	^ WAAdmin register: self at: aString in: aDispatcher! !

!WAPackage class methodsFor: '*seaside-environment' stamp: 'lr 11/30/2008 13:40'!
seasideEnvironment
	^ self new
		name: 'Seaside-Environment';
		description: 'Administrative tools, useful to have for productive and development environments.';
		addDependency: 'Seaside-Core';
		addDependency: 'Seaside-Component';
		addDependency: 'Seaside-RenderLoop';
		addDependency: 'Seaside-Session';
		addDependency: 'Seaside-Canvas';
		yourself! !

WAFileHandlerListing subclass: #WAHtmlFileHandlerListing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlFileHandlerListing methodsFor: 'responding' stamp: 'jf 11/9/2008 17:32'!
responseForLibraries
	| title |
	title := 'Index of ', handler basePath.
	^ WARenderCanvas builder
		rootBlock: [ :html | html title: title ];
		renderResponse: [ :html |
			html heading: title.
			html unorderedList: [
				handler libraries do: [ :each |
					html listItem: [
						html anchor
							url: (each urlOf: '');
							with: each name ] ] ] ]! !

!WAHtmlFileHandlerListing methodsFor: 'responding' stamp: 'jf 11/9/2008 17:32'!
responseForLibrary: aLibrary
	| title |
	title := 'Index of ', aLibrary name.
	^ WARenderCanvas builder
		rootBlock: [ :html | html title: title ];
		renderResponse: [ :html |
			html heading level: 1; with: title.
			html table: [
				html tableRow: [
					html tableHeading: 'Name'.
					html tableHeading: 'Size'.
					html tableHeading: 'Description' ].
				aLibrary fileSelectors do: [ :each |
					html tableRow: [
						html tableData: [
							html anchor
								url: (aLibrary urlOf: each);
								with: (aLibrary asFilename: each) ].
						html tableData: (aLibrary perform: each) size.
						html tableData: (aLibrary mimetypeForFile: (aLibrary asFilename: each)) ] ] ] ]! !

WAResponseFactory subclass: #WAHtmlResponseFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlResponseFactory methodsFor: 'generation' stamp: 'lr 1/12/2009 15:10'!
forbidden
	self response
		forbidden;
		contentType: WAMimeType textHtml;
		nextPutAll: (WARenderCanvas builder
			fullDocument: true;
			rootBlock: [ :root | root title: 'Forbidden' ];
			render: [ :html |
				html heading: [
					html text: 'Error: you are forbidden to access "'.
					html text: self request url.
					html text: '"' ] ])! !

!WAHtmlResponseFactory methodsFor: 'generation' stamp: 'lr 1/12/2009 15:11'!
notFound
	self response
		notFound;
		contentType: WAMimeType textHtml;
		nextPutAll: (WARenderCanvas builder
			fullDocument: true;
			rootBlock: [ :root | root title: 'Not Found' ];
			render: [ :html |
				html heading: [
					html text: 'Error: "'.
					html text: self request url.
					html text: '" not found' ] ])! !

!WAHtmlResponseFactory methodsFor: 'generation' stamp: 'lr 1/12/2009 15:12'!
pageExpired
	self response
		doNotCache;
		contentType: WAMimeType textHtml;
		nextPutAll: (WARenderCanvas builder
			fullDocument: true;
			rootBlock: [ :root | root title: 'Page Expired' ];
			render: [ :html | 
				html heading: 'Page Expired'.
				html paragraph: 'This page has expired. Please use the back-button to navigate to the last valid page.' ])! !

!WAHtmlResponseFactory methodsFor: 'generation' stamp: 'lr 1/12/2009 15:13'!
refreshAfter: aNumber location: aUrlOrString message: aString
	self response
		contentType: WAMimeType textHtml;
		refreshAfter: aNumber location: aUrlOrString;
		nextPutAll: (WARenderCanvas builder
			fullDocument: true;
			render: [ :html |
				html heading: aString.
				html paragraph: [
					html text: 'You are being redirected to '.
					html anchor
						url: aUrlOrString;
						with: aUrlOrString seasideString ] ])! !

!WAComponent class methodsFor: '*seaside-environment' stamp: 'lr 12/30/2008 12:48'!
registerAsApplication: aString 
	self
		seasideDeprecatedApi: 'WAComponent class>>#registerAsApplication:'
		details: 'Use WAAdmin class>>#register:asApplicationAt:.'.
	^ WAAdmin register: self asApplicationAt: aString! !
WAAdmin initialize!
